==> graphics-style-0.2.6.crate: graphics-style-0.2.6/src/traits/convert.rs <==
use super::*;

impl From<f32> for PointSize {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for PointSize {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for PointColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for PointColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for CircleWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for CircleWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for CircleColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for CircleColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<RGBA> for DiskFillColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for DiskFillColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for DiskEdgeWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for DiskEdgeWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for DiskEdgeColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for DiskEdgeColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for LineWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for LineWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for LineColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for LineColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl PartialEq<f32> for PointSize {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for PointSize {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for CircleWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for CircleWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for DiskEdgeWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for DiskEdgeWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for LineWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for LineWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

==> graphics-style-0.2.7.crate: graphics-style-0.2.7/src/traits/convert.rs <==
use super::*;

impl From<f32> for PointSize {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for PointSize {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for PointColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for PointColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for CircleWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for CircleWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for CircleColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for CircleColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<RGBA> for DiskFillColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for DiskFillColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for DiskEdgeWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for DiskEdgeWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for DiskEdgeColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for DiskEdgeColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for LineWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for LineWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for LineColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for LineColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for TriangleEdgeWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for TriangleEdgeWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for TriangleFillColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for TriangleFillColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl From<f32> for SquareEdgeWidth {
    fn from(value: f32) -> Self {
        Self { value }
    }
}

impl Into<f32> for SquareEdgeWidth {
    fn into(self) -> f32 {
        self.value
    }
}

impl From<RGBA> for SquareFillColor {
    fn from(value: RGBA) -> Self {
        Self { value }
    }
}

impl Into<RGBA> for SquareFillColor {
    fn into(self) -> RGBA {
        self.value
    }
}

impl PartialEq<f32> for PointSize {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for PointSize {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for CircleWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for CircleWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for DiskEdgeWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for DiskEdgeWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for LineWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for LineWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for TriangleEdgeWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for TriangleEdgeWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}

impl PartialEq<f32> for SquareEdgeWidth {
    fn eq(&self, other: &f32) -> bool {
        self.value.eq(other)
    }
}

impl PartialOrd<f32> for SquareEdgeWidth {
    fn partial_cmp(&self, other: &f32) -> Option<Ordering> {
        self.value.partial_cmp(other)
    }
}
